@@ -232,7 +232,8 @@ panel.3dscatter <-
             tmpcol0 <- col.line[ord][-1]
             tmpcol1 <- col.line[ord][-tmplen]
 
-            tmpcol0[tmpcol0 != tmpcol1] <- "transparent"
+            ## segments shouldn't join points in different groups 
+            tmpcol0[ groups[ord][-1] != groups[ord][-tmplen] ] <- "transparent"
 
             m0 <- ltransform3dto3d(rbind(tmpx0, tmpy0, tmpz0), rot.mat, distance)
             m1 <- ltransform3dto3d(rbind(tmpx1, tmpy1, tmpz1), rot.mat, distance)
@@ -350,9 +351,9 @@ panel.3dwire <-
                 bg[["col"]] <- "white"
             bg
         }
+
     numcol <- length(at) - 1
     numcol.r <- length(col.regions)
-
     col.regions <-
         if (numcol.r <= numcol)
             rep(col.regions, length = numcol)
@@ -667,7 +668,7 @@ panel.cloud <-
 
 
 
-    if (any(subscripts))  ## otherwise nothing to draw (not even box ?)
+    if (length(subscripts) > 0)  ## otherwise nothing to draw (not even box ?)
     {
 
         ## figure out data ranges and tick locations / labels
@@ -1663,7 +1664,7 @@ cloud.formula <-
             else if (xlog == "e") exp(1)
 
         x <- log(x, xbase)
-        if (!missing(xlim)) xlim <- log(xlim, xbase)
+        if (!missing(xlim)) xlim <- logLimits(xlim, xbase)
     }
     if (have.ylog)
     {
@@ -1674,7 +1675,7 @@ cloud.formula <-
             else if (ylog == "e") exp(1)
 
         y <- log(y, ybase)
-        if (!missing(ylim)) ylim <- log(ylim, ybase)
+        if (!missing(ylim)) ylim <- logLimits(ylim, ybase)
     }
     if (have.zlog)
     {
@@ -1685,7 +1686,7 @@ cloud.formula <-
             else if (zlog == "e") exp(1)
 
         z <- log(z, zbase)
-        if (!missing(zlim)) zlim <- log(zlim, zbase)
+        if (!missing(zlim)) zlim <- logLimits(zlim, zbase)
     }
 
     ## Step 5: Process cond
